==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/client/render/block_entity/IncensePlateBlockEntityRenderer.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.render.block_entity;

import net.minecraft.class_1160;
import net.minecraft.class_1799;
import net.minecraft.class_2350;
import net.minecraft.class_2741;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_809;
import net.minecraft.class_827;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.common.block.block_entity.IncensePlateBlockEntity;

public class IncensePlateBlockEntityRenderer implements class_827<IncensePlateBlockEntity> {
	public IncensePlateBlockEntityRenderer(class_5614.class_5615 ctx) {}

	@Override
	public void render(@NotNull IncensePlateBlockEntity plate, float ticks, class_4587 ms, class_4597 buffers, int light, int overlay) {
		class_1799 stack = plate.getItemHandler().method_5438(0);
		if (stack.method_7960()) {
			return;
		}

		class_2350 facing = plate.method_11010().method_11654(class_2741.field_12481);

		ms.method_22903();
		ms.method_22904(0.5F, 1.5F, 0.5F);
		int degrees = switch (facing) {
			default -> 0;
			case field_11039 -> 90;
			case field_11035 -> 180;
			case field_11034 -> 270;
		};
		ms.method_22907(class_1160.field_20705.method_23214(degrees));
		float s = 0.6F;
		ms.method_22904(-0.11F, -1.35F, 0F);
		ms.method_22905(s, s, s);
		class_310.method_1551().method_1480().method_23178(stack, class_809.class_811.field_4318,
				light, overlay, ms, buffers, 0);
		ms.method_22909();
	}

}

==> Botania-1.20.1-451-FABRIC-20260131.092931-41-sources.jar: vazkii/botania/client/render/block_entity/IncensePlateBlockEntityRenderer.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.render.block_entity;

import net.minecraft.class_1799;
import net.minecraft.class_2350;
import net.minecraft.class_2741;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5614;
import net.minecraft.class_811;
import net.minecraft.class_827;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.common.block.block_entity.IncensePlateBlockEntity;
import vazkii.botania.common.helper.VecHelper;

public class IncensePlateBlockEntityRenderer implements class_827<IncensePlateBlockEntity> {
	public IncensePlateBlockEntityRenderer(class_5614.class_5615 ctx) {}

	@Override
	public void render(@NotNull IncensePlateBlockEntity plate, float ticks, class_4587 ms, class_4597 buffers, int light, int overlay) {
		class_1799 stack = plate.getItemHandler().method_5438(0);
		if (stack.method_7960()) {
			return;
		}

		class_2350 facing = plate.method_11010().method_11654(class_2741.field_12481);

		ms.method_22903();
		ms.method_46416(0.5F, 1.5F, 0.5F);
		int degrees = switch (facing) {
			default -> 0;
			case field_11039 -> 90;
			case field_11035 -> 180;
			case field_11034 -> 270;
		};
		ms.method_22907(VecHelper.rotateY(degrees));
		float s = 0.6F;
		ms.method_46416(-0.11F, -1.35F, 0F);
		ms.method_22905(s, s, s);
		class_310.method_1551().method_1480().method_23178(stack, class_811.field_4318,
				light, overlay, ms, buffers, plate.method_10997(), 0);
		ms.method_22909();
	}

}
